// $Id: process.cpp,v 1.1 2008/08/18 05:34:36 esmondpitt Exp $

/****************************************************************************
 * Copyright (C) 2003, 2004 Patrick Charles and Jonas Lehmann				*
 * Copyright (C) 2008 Esmond Pitt											*
 * Distributed under the Mozilla Public License								*
 *   http://www.mozilla.org/NPL/MPL-1.1.txt									*
 ***************************************************************************/

#include <assert.h>

#include "jnu.hpp"
#include "process.hpp"

// pcap_handler_thunk
void	PcapCallback::pcap_handler_thunk(u_char *user, const struct pcap_pkthdr *h, const u_char *sp)
{
	PcapCallback	*pcb = (PcapCallback*)user;
	pcb->handlePacket(h, sp);
}

/**
 * Constructor
 */
PacketProcessor::PacketProcessor(const JNUEnv &env, jobject self, const JNUVoidMethod &callback)
		 : _env(env),
		 _self(self),
		 _callback(callback)
{
}

/*
 * Thunk to Java callback
 */
void PacketProcessor::handlePacket(const struct pcap_pkthdr *h, const u_char *sp) {

	int seconds = h->ts.tv_sec;
	int useconds = h->ts.tv_usec;
	
	//  if(VERBOSE) {
	//	(void)printPacket(user, sp, h->caplen, h->len, seconds, useconds);
	//  }
	
	// Declare a local frame
	JNULocalFrame	localFrame();

	/* Check to see if any unhandled exceptions are pending in the VM before
	calling back the packet handler. If an exception is pending, return
	control immediately so that the VM can handle it.
	*/
	if(_env->ExceptionCheck())
		return;

	//  printf("PacketProcessor::handlePacket caplen=%d\n", h->caplen); fflush(stdout);
	
	// dispatch captured data to the handle method in the java capture object..
	_callback.invoke(
		_self,
		h->len,
		h->caplen,
		seconds,
		useconds,
		(jobject)JNUByteBuffer::wrap(const_cast<u_char*>(sp), h->caplen));
	
}


