// $Id: process.hpp,v 1.1 2008/08/18 05:34:36 esmondpitt Exp $

/***************************************************************************
 * Copyright (C) 2003, 2004 Patrick Charles and Jonas Lehmann		   *
 * Distributed under the Mozilla Public License				   *
 *   http://www.mozilla.org/NPL/MPL-1.1.txt				   *
 ***************************************************************************/

extern "C" {
#include <pcap.h>
}
#include <jni.h>

/**
 * Encapsulation of packet processing, with management of separate instances,
 *
 * Submitted by Anatol Novchenko, along with numerous changes to jpcap.c.
 *
 * Revised by Esmond Pitt to cure multiple memory leaks, improve performance,
 * and unify the processing of all pcap_handler callbacks.
 */

/*
 * Base class for all callback classes.
 */ 
class PcapCallback
{
public:
	// Virtual dtor, just in case we need it ...
	virtual	~PcapCallback() {}

	/*
	* Callback, satisfying the signature of pcap_handler signature,
	* called by pcap_loop()/pcap_dispatch() for processing packet data.
	* This method thunks to the virtual handlePacket()
	* method, which does whatever the derived class wants to do with it.
	*/
	static void	pcap_handler_thunk(u_char *user, const struct pcap_pkthdr *h, const u_char *sp);

protected:
	virtual void	handlePacket(const struct pcap_pkthdr *h, const u_char *sp) = 0;
};

/*
 * PacketProcessor callback class.
 * This one calls PacketCaptureBase.handlePacket()
 */
class PacketProcessor : public PcapCallback
{

 public:
	 // ctor
	 PacketProcessor(const JNUEnv &env, jobject self, const JNUVoidMethod &callback);

	 // Thunk to Java callback
	 void handlePacket(const struct pcap_pkthdr *h, const u_char *sp);

 private:
	JNUEnv		_env;			// Java env for this thread
	jobject		_self;			// Java object hooked into this wrapper lib.
	JNUVoidMethod _callback;	// methodID of the callback method in the class

};

