// $Id: CaptureStatistics.java,v 1.2 2008/08/18 05:34:36 esmondpitt Exp $

/***************************************************************************
 * Copyright (C) 2001, Patrick Charles and Jonas Lehmann                   *
 * Copyright (C) 2008, Esmond Pitt                                         *
 * Distributed under the Mozilla Public License                            *
 *   http://www.mozilla.org/NPL/MPL-1.1.txt                                *
 ***************************************************************************/
package net.sourceforge.jpcap.capture;


/**
 * Packet capture statistics.
 * <p>
 * Encapsulation for statistics collected by PacketCapture.
 *
 * @author Patrick Charles
 * @author Jonas Lehmann
 * @author Esmond Pitt
 * @version $Revision: 1.2 $
 * @lastModifiedBy $Author: esmondpitt $
 * @lastModifiedAt $Date: 2008/08/18 05:34:36 $
 */
public class CaptureStatistics
{
  /**
   * Create a new instance of CaptureStatistics.
   */
  public CaptureStatistics() {}
  
  /**
   * Create a new and empty statistics container.
   * @param receivedCount Count of packets received
   * @param droppedCount Count of packets dropped
   * @param droppedCount Count of packets dropped
   * @param droppedByInterfaceCount Count of packets dropped by interface
   * @param receivedByApplicationCount Count of packets received by application
   * @param sentByServerCount Count of packets sent by server
   * @param droppedByNetworkCount Count of packets dropped by the network
   */
  CaptureStatistics(int receivedCount, int droppedCount, int droppedByInterfaceCount, int receivedByApplicationCount, int sentByServerCount, int droppedByNetworkCount) {
    this.receivedCount = receivedCount;
    this.droppedCount = droppedCount;
	this.droppedByInterfaceCount = droppedByInterfaceCount;
	this.receivedByApplicationCount = receivedByApplicationCount;
	this.sentByServerCount = sentByServerCount;
	this.droppedByNetworkCount = droppedByNetworkCount;
  }
  
  /**
   * Create a new and empty statistics container.
   * @param receivedCount Count of packets received
   * @param droppedCount Count of packets dropped
   */
  public CaptureStatistics(int receivedCount, int droppedCount) {
    this.receivedCount = receivedCount;
    this.droppedCount = droppedCount;
  }

  /**
   * Return the number of packets received
   * @return the number of packets received
   */
  public int getReceivedCount() {
    return receivedCount;
  }

  /**
   * Return the number of packets dropped
   * @return the number of packets dropped
   */
  public int getDroppedCount() {
    return droppedCount;
  }

	/**
	 * Return the number of packets dropped by interface XXX not yet supported
	 * @return the number of packets dropped by interface
	 */
	public int getDroppedByInterfaceCount()
	{
		return droppedByInterfaceCount;
	}

	/**
	 * Return the number of packets received by the application.
	 * Only returns non-zero in <i>libpcap</i> environments with HAVE_REMOTE.
	 * @return the number of packets received by the application.
	 */
	public int getReceivedByApplicationCount()
	{
		return receivedByApplicationCount;
	}

	/**
	 * Return the number of packets sent by the server.
	 * Only returns non-zero in <i>libpcap</i> environments with HAVE_REMOTE.
	 * @return the number of packets sent by the server.
	 */
	public int getSentByServerCount()
	{
		return sentByServerCount;
	}

	/**
	 * Return the number of packets dropped by the network.
	 * Only returns non-zero in <i>libpcap</i> environments with HAVE_REMOTE.
	 * @return the number of packets dropped by the network.
	 */
	public int getDroppedByNetworkCount()
	{
		return droppedByNetworkCount;
	}


  /**
   * Convert this packet to a readable string.
   */
  public String toString() {
    StringBuffer buffer = new StringBuffer();
    buffer.append("[CaptureStatistics: ");
    buffer.append("received = " + receivedCount);
    buffer.append(", dropped = " + droppedCount);
    buffer.append(", droppedByInterface = " + droppedByInterfaceCount);
    buffer.append(", receivedByApplication = " + receivedByApplicationCount);
    buffer.append(", sentByServer = " + sentByServerCount);
    buffer.append(", droppedByNetwork = " + droppedByNetworkCount);
    buffer.append(']');

    return buffer.toString();
  }

  private int receivedCount;
  private int droppedCount;
  private int droppedByInterfaceCount;
  private int receivedByApplicationCount;
  private int sentByServerCount;
  private int droppedByNetworkCount;

  private static final String _rcsid = 
    "$Id: CaptureStatistics.java,v 1.2 2008/08/18 05:34:36 esmondpitt Exp $";
}
