/*
 * PacketInputStream.java
 *
 * Created on 10 May 2008, 12:23
 *
 * Copyright (c) Esmond Pitt, 2007. All rights reserved.
 */

package net.sourceforge.jpcap.capture;

import java.io.EOFException;
import java.io.IOException;
import java.io.InputStream;
import java.net.SocketTimeoutException;
import net.sourceforge.jpcap.net.Packet;

/**
 * PacketInputStream provides an easy way of reading packets from the network or a savefile
 * without having to define and register {@link PacketListener PacketListeners}.
 *
 * @see PacketCapture#getInputStream()
 *
 * @author Esmond Pitt
 * @version $Revision: 1.1 $
 * @since 2.0.0
 */
public abstract class PacketInputStream extends InputStream
{
	
	/** Creates a new instance of PacketInputStream */
	protected PacketInputStream()
	{
	}
	
	/**
	 * {@inheritDoc}
	 *
	 * Closing the stream stops all the associated capture activities.
	 */
	public abstract void	close() throws IOException;

	/**
	 * {@inheritDoc}
	 *<p>
	 * This implementation throws UnsupportedOperationException.
	 */
	public int	read() throws IOException
	{
		throw new UnsupportedOperationException("read()");
	}

	/**
	 * {@inheritDoc}
	 *<p>
	 * This implementation throws UnsupportedOperationException.
	 */
	public int	read(byte[] buffer) throws IOException
	{
		throw new UnsupportedOperationException("read(byte[])");
	}

	/**
	 * {@inheritDoc}
	 *<p>
	 * This implementation throws UnsupportedOperationException.
	 */
	public int	read(byte[] buffer, int offset, int length) throws IOException
	{
		throw new UnsupportedOperationException("read(byte[], int, int)");
	}
	
	/**
	 * Read a Packet from the network or savefile, depending on how the stream was constructed.
	 * @return a Packet.
	 * @exception SocketTimeoutException The timeout specified when the capture device was opened has expired without a packet being captured.
	 * @exception EOFException End of a savefile has been reached.
	 * @exception IOException I/O problem reading packet.
	 */
	public abstract Packet	readPacket() throws SocketTimeoutException, EOFException, IOException;
	
}
