/*
 * StatisticsEvent.java
 *
 * Created on 22 May 2008, 15:45
 * Copyright (C) 2008, Esmond Pitt                                         *
 * Distributed under the Mozilla Public License                            *
 *   http://www.mozilla.org/NPL/MPL-1.1.txt                                *
 ***************************************************************************/

package net.sourceforge.jpcap.capture;

import java.util.EventObject;
import net.sourceforge.jpcap.util.Timeval;

/**
 * StatisticsEvent encapsulates the statistics generated by {@link JWinPcap.CaptureMode#Statistical}.
 *
 * @see JWinPcap.CaptureMode#Statistical
 * @see StatisticsListener#statisticsArrived
 * @see JWinPcap#addStatisticsListener
 * @see JWinPcap#removeStatisticsListener
 * @see <a href="http://www.winpcap.org/docs/docs_40_2/html/group__wpcap__tut9.html">
 * Gathering Statistics on the network traffic</a>
 *
 * @author Esmond Pitt
 * @version $Revision: 1.1 $
 */
public class StatisticsEvent extends EventObject
{
	static final long serialVersionUID = -3489763929099542203L;
	
	/**
	 * Creates a new instance of StatisticsEvent.
	 * @param packets packets/second since last call
	 * @param bytes bytes/second since last call
	 * @param tv Timeval timestamp
	 */
	StatisticsEvent(Object source, long packets, long bytes, Timeval timeval)
	{
		super(source);
		this.packets = packets;
		this.bytes = bytes;
		this.timeval = timeval;
	}
	
	public String	toString()
	{
		return "StatisticsEvent: packets="+packets+":bytes="+bytes+":tv="+timeval;
	}

	/**
	 * Holds value of property packets.
	 */
	private long packets;

	/**
	 * Getter for property packets.
	 * @return Value of property packets.
	 */
	public long getPackets()
	{
		return this.packets;
	}

	/**
	 * Holds value of property bytes.
	 */
	private long bytes;

	/**
	 * Getter for property bytes.
	 * @return Value of property bytes.
	 */
	public long getBytes()
	{
		return this.bytes;
	}

	/**
	 * Holds value of property timeval.
	 */
	private Timeval timeval;

	/**
	 * Getter for property timeval.
	 * @return Value of property timeval.
	 */
	public Timeval getTimeval()
	{
		return this.timeval;
	}
	
}
