// $Id: IPPacket.java,v 1.2 2008/08/18 05:34:37 esmondpitt Exp $

/***************************************************************************
 * Copyright (C) 2001, Patrick Charles and Jonas Lehmann                   *
 * Copyright (C) 2008, Esmond Pitt                                         *
 * Distributed under the Mozilla Public License                            *
 *   http://www.mozilla.org/NPL/MPL-1.1.txt                                *
 ***************************************************************************/
package net.sourceforge.jpcap.net;

import net.sourceforge.jpcap.util.AnsiEscapeSequences;
import net.sourceforge.jpcap.util.Timeval;
import java.net.Inet4Address;
import java.net.InetAddress;
import java.net.UnknownHostException;
import java.nio.ByteBuffer;


/**
 * An IP protocol packet.
 * <p>
 * Extends an ethernet packet, adding IP header information and an IP  data payload. 
 *
 * @author Patrick Charles
 * @author Jonas Lehmann
 * @author Esmond Pitt
 * @version $Revision: 1.2 $
 * @lastModifiedBy $Author: esmondpitt $
 * @lastModifiedAt $Date: 2008/08/18 05:34:37 $
 */
public class IPPacket extends IPv4.Packet implements IPFields
{
	static final long serialVersionUID = 9096847756936610697L;

  /** 
   * Create a new IP packet. 
   * @param lLen link-layer header length
   * @param bytes Packet data
   */
  public IPPacket(int lLen, byte [] bytes) {
    this(lLen, bytes, null);
  }

  /**
   * Create a new IP packet.
   * @param lLen link-layer header length
   * @param bytes Packet data
   * @param tv Timestamp
   */
  public IPPacket(int lLen, byte [] bytes, Timeval tv) {
    this(lLen, ByteBuffer.wrap(bytes), tv);
  }

  /** 
   * Create a new IP packet. 
   * @param lLen link-layer header length
   * @param bb Packet data in a ByteBuffer
   * @param tv Timestamp
   * @since 2.0.0
   */
  public IPPacket(int lLen, ByteBuffer bb, Timeval tv) {
    super(lLen, bb, tv);
    // fetch the actual header length from the incoming bytes
//    _ipHeaderLength = 
//      (ArrayHelper.extractInteger(_bytes,_ethOffset+IP_VER_POS,
//				   IP_VER_LEN) & 0xf) * 4;
  }

  /** 
   * Fetch the IP header length in bytes.
   * @deprecated Please use {@link #getIPHeaderLength}
   */
  @Deprecated
  public int getIpHeaderLength() {
    // this is the old method call, but everything else uses all caps for
    // TCP, so in the interest of consistency...
    return getIPHeaderLength();
  }

  /** 
   * Fetch the IP address of the host where the packet originated from.
   * @deprecated Please use {@link #getSourceInetAddress}
   * @return the source IP address
   */
  @Deprecated
  public String getSourceAddress() {
	  return getSourceInetAddress().getHostAddress();
  }

  /** 
   * Fetch the source IP address as a byte array.
   * @deprecated Please use {@link #getSourceInetAddress}
   * @return the source IP address as a byte array
   */
  @Deprecated
  public byte[] getSourceAddressBytes() {
	  return getSourceInetAddress().getAddress();
  }

  /** 
   * Fetch the source IP address as a long.
   * @deprecated Too long for IPv4 and not long enough for IPv6: please use {@link #getSourceInetAddress}
   * @return the source IP address as a long
   */
  @Deprecated
  public long getSourceAddressAsLong() {
//	return ArrayHelper.extractLong(_bytes, _ethOffset + IP_SRC_POS, IPAddress.WIDTH);
	  return _byteBuffer.getInt(_ethOffset+IP_SRC_POS) & 0xffffffffL;
  }

  /** 
   * Fetch the IP address of the host where the packet is destined.
   * @deprecated Please use {@link #getDestinationInetAddress}
   * @return the destination IP address
   */
  public String getDestinationAddress() {
	  return getDestinationInetAddress().getHostAddress();
  }

  /** 
   * Fetch the destination IP address as a byte array.
   * @deprecated Please use {@link #getDestinationInetAddress}
   * @return the destination IP address as a byte array
   */
  @Deprecated
  public byte[] getDestinationAddressBytes() {
	  return getDestinationInetAddress().getAddress();
  }

  /** 
   * Fetch the destination IP address as a long.
   * @deprecated Too long for IPv4 and not long enough for IPv6: please use {@link #getDestinationInetAddress}
   * @return the destination IP address as a long
   */
  @Deprecated
  public long getDestinationAddressAsLong() {
//      return ArrayHelper.extractLong(_bytes, _ethOffset + IP_DST_POS, IPAddress.WIDTH);
	  return _byteBuffer.getInt(_ethOffset+IP_DST_POS) & 0xffffffffL;
  }

  /**
   * Provided for binary compability only. No longer used.
   * Now calls {@link Packet#ipChecksum}
   * @deprecated Please call {@link Packet#ipChecksum}.
   */
  @Deprecated
  protected int	onesCompSum(byte[] bytes, int offset, int len)
  {
	  return ~ipChecksum(bytes, offset, len) & 0xffff;
  }
 
  /** 
   * This inner class provides access to private methods for unit testing.
   */
  public class TestProbe {
    public int getComputedReceiverIPChecksum() {
      return IPPacket.this.computeReceiverIPChecksum();
    }
    public int getComputedSenderIPChecksum() {
      return IPPacket.this.computeSenderIPChecksum();
    }
  }


  private static final String _rcsid = 
    "$Id: IPPacket.java,v 1.2 2008/08/18 05:34:37 esmondpitt Exp $";
}
