/*
 * ISL.java
 *
 * Created on 27 May 2008, 17:03
 *
 * Copyright (c) Esmond Pitt, 2007. All rights reserved.
 */

package net.sourceforge.jpcap.net;

import java.nio.ByteBuffer;
import net.sourceforge.jpcap.util.Timeval;

/**
 * ISL (Inter-Switch Link) protocol.
 * This is very much a work-in-progress.
 * 
 * @see <a href="http://www.cisco.com/en/US/tech/tk389/tk689/technologies_tech_note09186a0080094665.shtml#topic1">
 * Inter-Switch Link and IEEE 802.1Q Frame Format</a>
 * 
 * @author Esmond Pitt
 * @version $Revision: 1.1 $
 * @since 2.0.0
 */
public interface ISL
{
	/**
	 * ISL multicast addresses.
	 * 
	 * @see <a href="http://www.cisco.com/en/US/tech/tk389/tk689/technologies_tech_note09186a0080094665.shtml#topic1">ISL frame definition</a>
	 */
	public static final byte[]	ISL1 = {0x01, 0x00, 0x0C, 0x00, 0x00},
								ISL2 = {0x03, 0x00, 0x0C, 0x00, 0x00};
	public static final int	ISL_HEADER_SIZE = 0x1a;
	
	/**
	 * ISL Packet class.
	 * 
	 * @see <a href="http://www.cisco.com/en/US/tech/tk389/tk689/technologies_tech_note09186a0080094665.shtml#topic1">
	 * Inter-Switch Link and IEEE 802.1Q Frame Format</a>
	 *
	 * @author Esmond Pitt
	 * @version $Revision: 1.1 $
	 * @since 2.0.0.
	 */
	class Packet extends EthernetPacket
	{
		static final long serialVersionUID = 3816188730521693163L;
		
		// Instance data
		private EthernetPacket ethernetPacket;
		
		/** Creates a new instance of ISL.Packet */
		public Packet(int lLen, byte[] bytes, Timeval tv)
		{
			super(lLen, bytes, tv);
		}
		
		/** Creates a new instance of ISL.Packet */
		public Packet(int lLen, ByteBuffer bb, Timeval tv)
		{
			super(lLen, bb, tv);
		}
		
		/**
		 * @return the ISL header data.
		 */
		public byte[]	getISLHeader()
		{
			return null;
		}
		
		/**
		 * @return the ISL packet data.
		 */
		public byte[]	getISLData()
		{
			return null;
		}
		
		/**
		 * @return the embedded Ethernet packet
		 */
		public EthernetPacket	getEthernetPacket()
		{
			return ethernetPacket;
		}
		
		void	setEthernetPacket(EthernetPacket ethernetPacket)
		{
			this.ethernetPacket = ethernetPacket;
		}
	}
}
