/*
 * LLC.java
 *
 * Created on 29 May 2008, 09:57
 *
 * Copyright (c) Esmond Pitt, 2007. All rights reserved.
 */

package net.sourceforge.jpcap.net;

import java.math.BigInteger;
import java.nio.ByteBuffer;
import net.sourceforge.jpcap.util.Timeval;

/**
 *
 * @author Esmond Pitt
 * @version $Revision: 1.1 $
 *
 * @since 2.0.0
 */
public interface LLC
{
	/**
	 * Offset of LLC header
	 */
	int	LLC_HEADER_POS = 0;

	/**
	 * Offset of DSAP
	 */
	int LLC_DSAP_POS = LLC_HEADER_POS;
	
	/**
	 * Length of DSAP
	 */
	int LLC_DSAP_LEN = 1;
	
	/**
	 * Offset of SSAP
	 */
	int LLC_SSAP_POS = LLC_DSAP_POS+LLC_DSAP_LEN;
	
	/**
	 * Length of SSAP
	 */
	int LLC_SSAP_LEN = 1;
	
	/**
	 * Offset of Control
	 */
	int LLC_CONTROL_POS = LLC_SSAP_POS+LLC_SSAP_LEN;
	
	/**
	 * Length of Control
	 */
	int LLC_CONTROL_LEN = 1;
	
	/**
	 * Offset of protocol
	 */
	int LLC_PROTOCOL_POS = LLC_CONTROL_POS+LLC_CONTROL_LEN;
	/**
	 * Length of protocol
	 */
	int LLC_PROTOCOL_LEN = 2;
	/**
	 * LLC Header length.
	 */
	int LLC_HEADER_LEN = LLC_DSAP_LEN+LLC_SSAP_LEN+LLC_CONTROL_LEN+LLC_PROTOCOL_LEN;
	
	// Service Access Point (DSAP/SSAP) values
	/**
	 * Spanning Tree Protocol (STP)
	 */
	byte	SAP_STP = 0x42;
	/**
	 * SubNet Access Protocol (SNAP)
	 */
	byte	SAP_SNAP = (byte)0xaa;
	// Control information values
	/**
	 * Unnumbered information type
	 */
	byte	LLC_UNNUMBERED_INFORMATION = 0x03;
	
	class PacketFactory extends net.sourceforge.jpcap.net.PacketFactory
	{
		private PacketFactory(){}
		
		public static Packet	dataToPacket(int lLen, ByteBuffer bb, Timeval tv)
		{
			// It's an 802.3 packet.
			int offset = lLen;	// skip protocol/length field
			byte	dsap = bb.get(offset+LLC.LLC_DSAP_POS);
			byte	ssap = bb.get(offset+LLC.LLC_SSAP_POS);
			// Ethernet802.3.dsapssap.0x4242=net.sourceforge.jpcap.net.STP$Packet
			int	dsapssap = ((dsap & 0xff) << 8) | (ssap & 0xff);
//			System.out.println("LLC.PacketFactory: offset="+offset+": dsap/ssap=0x"+Integer.toHexString(dsapssap));
			String	key = ETHERNET8023_PREFIX
				+"dsapssap.0x"+Integer.toHexString(0x10000+dsapssap).substring(1);
			Packet	p = createPacket(key, lLen, bb, tv);
			if (p != null)
				return p;
			byte	control = bb.get(offset+LLC.LLC_CONTROL_POS);
//			System.out.println("LLC.PacketFactory: switching on 0x"+Integer.toHexString((dsapssap << 8)|control));
			switch ((dsapssap << 8)|control)
			{
				case (SAP_STP << 16)|(SAP_STP << 8)|LLC_UNNUMBERED_INFORMATION:
					// STP
					return new STP.Packet(lLen, bb, tv);
				case ((SAP_SNAP & 0xff) << 16)|((SAP_SNAP & 0xff) << 8)|LLC_UNNUMBERED_INFORMATION:
					return SNAP.PacketFactory.dataToPacket(lLen, bb, tv);
			}
			return null;
		}
	}
	
}
