/*
 * SNAP.java
 *
 * Created on 29 May 2008, 09:59
 *
 * Copyright (c) Esmond Pitt, 2007. All rights reserved.
 */

package net.sourceforge.jpcap.net;

import java.lang.reflect.Constructor;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.nio.ByteBuffer;
import net.sourceforge.jpcap.util.Timeval;

/**
 * SNAP interface definitions.
 *
 * @author Esmond Pitt
 * @version $Revision: 1.1 $
 *
 * @since 2.0.0
 */
public interface SNAP extends LLC
{
	/**
	 * Definitions for SNAP fields
	 * @author Esmond Pitt
	 * @version $Revision: 1.1 $
	 */
	/**
	 * Offset of SNAP header
	 */
	int SNAP_HEADER_POS = LLC_HEADER_POS+LLC_HEADER_LEN-LLC_PROTOCOL_LEN;
	/**
	 * Offset of Organization
	 */
	int SNAP_ORG_POS = SNAP_HEADER_POS;
	
	/**
	 * Length of Organization
	 */
	int SNAP_ORG_LEN = 3;
	
	/**
	 * Offset of Protocol
	 */
	int SNAP_PROTOCOL_POS = SNAP_ORG_POS+SNAP_ORG_LEN;
	
	/**
	 * Length of Protocol
	 */
	int SNAP_PROTOCOL_LEN = 2;
	/**
	 * SNAP header length
	 */
	int SNAP_HEADER_LEN = SNAP_ORG_LEN+SNAP_PROTOCOL_LEN;
	
	/**
	 * Offset of MIB type (relative)
	 */
	int MIB_TYPE_POS = 0;
	/**
	 * Length of MIB type
	 */
	int MIB_TYPE_LEN = 2;
	/**
	 * Offset of MIB length (relative)
	 */
	int MIB_LENGTH_POS = 2;
	/**
	 * Length of MIB length
	 */
	int MIB_LENGTH_LEN = 2;
	/**
	 * Offset of MIB value (relative)
	 */
	int MIB_VALUE_POS = 4;
	/**
	 * IEEE organization code.
	 */
	int	ORG_CODE_IEEE	= 0x000000;	// all zeros	
	/**
	 * Cisco organization code.
	 */
	int ORG_CODE_CISCO	= 0x00000c;	// C for Cisco
	
	// Protocols
	/**
	 * Cisco Discovery Protocol
	 */
	int	CDP = 0x2000;
	/**
	 * Dynamic Trunking Protocol
	 */
	int DTP = 0x2004;
	
	/**
	 * Packet factory
	 */
	class PacketFactory extends net.sourceforge.jpcap.net.PacketFactory
	{
		private PacketFactory(){}
		
		public static Packet	dataToPacket(int lLen, ByteBuffer bb, Timeval tv)
		{
			int	offset = lLen;
			byte	dsap = bb.get(offset+LLC.LLC_DSAP_POS);
			// System.out.println("dsap=0x"+Integer.toHexString(dsap));
			byte	ssap = bb.get(offset+LLC.LLC_SSAP_POS);
			int	dsapssap = ((dsap & 0xff) << 8) | (ssap & 0xff);
//			System.out.println("SNAP.PacketFactory: offset="+offset+": dsap/ssap=0x"+Integer.toHexString(dsapssap));
			// It's a SNAP packet
			int	org = bb.getInt(offset+SNAP_ORG_POS) >>> 8;
			int	snapProtocol = bb.getShort(offset+SNAP_PROTOCOL_POS) & 0xffff;
			// Ethernet802.3.dsapssap.0xaaaa.org.0x000c.protocol.0x2000
			String	key = ETHERNET8023_PREFIX
				+"dsapssap.0x"+Integer.toHexString(0x10000+dsapssap).substring(1)
				+".org.0x"+Integer.toHexString(0x1000+org).substring(1)
				+".protocol.0x"+Integer.toHexString(0x10000+snapProtocol).substring(1);
			Packet	p = createPacket(key, lLen, bb, tv);
			if (p != null)
				return p;
//			System.out.println("SNAP.PacketFactory: offset="+offset+": switching on org=0x"+Integer.toHexString(0x1000+org).substring(1));
			switch (org)
			{
			case ORG_CODE_CISCO:
//				System.out.println("SNAP.PacketFactory: org=Cisco offset="+offset+": snapProtocol=0x"+Integer.toHexString(snapProtocol));
				switch (snapProtocol)
				{
					case CDP:
						return new CDP.Packet(lLen, bb, tv);
					case DTP:
						return new DTP.Packet(lLen, bb, tv);
					default:
						// System.out.println("PacketFactory: unknown Cisco SNAP protocol 0x"+new BigInteger(bb.array()).toString(16));
						break;
				}
			}
			return null;
		}
	}
	
}
