// $Id: HexHelper.java,v 1.2 2008/08/18 05:34:48 esmondpitt Exp $

/***************************************************************************
 * Copyright (C) 2001, Patrick Charles and Jonas Lehmann                   *
 * Copyright (C) 2008, Esmond Pitt                                         *
 * Distributed under the Mozilla Public License                            *
 *   http://www.mozilla.org/NPL/MPL-1.1.txt                                *
 ***************************************************************************/
package net.sourceforge.jpcap.util;

/**
 * Functions for formatting and printing binary data in hexadecimal.
 *
 * @author Patrick Charles and Jonas Lehmann
 * @author Esmond Pitt
 * @version $Revision: 1.2 $
 * @lastModifiedBy $Author: esmondpitt $
 * @lastModifiedAt $Date: 2008/08/18 05:34:48 $
 */
public class HexHelper
{
  /**
   * Convert an int (32 bits in Java) to a decimal quad of the form
   * aaa.bbb.ccc.ddd.
   */
  public static String toQuadString(int i) {
    StringBuffer sb = new StringBuffer();
    for(int p=0; p<4; p++) {
      if(p > 0)
        sb.append('.');
      sb.append(i & 0xff);
      i >>>= 8;
    }
    return sb.toString();
  }

  /**
   * Convert an int to a hexadecimal string.
   */
  public static String toString(int i) {
	  return Long.toHexString(0x100000000L+i).substring(1);
  }

  /** 
   * Converts the lower four bits of a byte into the ascii digit 
   * which represents its hex value. For example:
   * nibbleToDigit(10) produces 'a'.
   */
  public static char nibbleToDigit(byte x) {
	  return Character.forDigit(x, 16);
  }

  /**
   * Convert a single byte into a string representing its hex value.
   * i.e. -1 -> "ff"
   * @param b the byte to convert.
   * @return a string containing the hex equivalent.
   */
  public static String toString(byte b) {
    return Integer.toHexString(0x100+(b & 0xff)).substring(1);
  }

  /**
   * Returns a text representation of a byte array.
   *
   * @param bytes a byte array
   * @return a string containing the hex equivalent of the bytes.
   */
  public static String toString(byte [] bytes) {
    StringBuffer sb = new StringBuffer();

    int length = bytes.length;
    if(length > 0) {
      for(int i = 0; i < length; i++) {
        if(i > 0)
          sb.append(" ");
        sb.append(toString(bytes[i]));
      }
    }
    return sb.toString();
  }


  static final String _rcsid = 
    "$Id: HexHelper.java,v 1.2 2008/08/18 05:34:48 esmondpitt Exp $";
}
